Package com.docusign.admin.model
Class SubAccountCreateTargetAccount
- java.lang.Object
-
- com.docusign.admin.model.SubAccountCreateTargetAccount
-
- All Implemented Interfaces:
Serializable
public class SubAccountCreateTargetAccount extends Object implements Serializable
SubAccountCreateTargetAccount.- See Also:
- Serialized Form
-
-
Constructor Summary
Constructors Constructor Description SubAccountCreateTargetAccount()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description SubAccountCreateTargetAccountadmin(SubAccountCreateTargetAccountAdmin admin)admin.SubAccountCreateTargetAccountcountryCode(String countryCode)countryCode.booleanequals(Object o)Compares objects.SubAccountCreateTargetAccountAdmingetAdmin()The admin user for the target account..StringgetCountryCode()The country code where the target account is in..UUIDgetId()The target account id being created.StringgetName()The name of the target account..StringgetRegion()The region where the target account is in..StringgetSite()The site where the target account is on..inthashCode()Returns the HashCode.SubAccountCreateTargetAccountid(UUID id)id.SubAccountCreateTargetAccountname(String name)name.SubAccountCreateTargetAccountregion(String region)region.voidsetAdmin(SubAccountCreateTargetAccountAdmin admin)setAdmin.voidsetCountryCode(String countryCode)setCountryCode.voidsetId(UUID id)setId.voidsetName(String name)setName.voidsetRegion(String region)setRegion.voidsetSite(String site)setSite.SubAccountCreateTargetAccountsite(String site)site.StringtoString()Converts the given object to string.
-
-
-
Method Detail
-
id
public SubAccountCreateTargetAccount id(UUID id)
id.- Returns:
- SubAccountCreateTargetAccount
-
getId
public UUID getId()
The target account id being created. It will be empty Guid if account is not created yet..- Returns:
- id
-
setId
public void setId(UUID id)
setId.
-
name
public SubAccountCreateTargetAccount name(String name)
name.- Returns:
- SubAccountCreateTargetAccount
-
getName
public String getName()
The name of the target account..- Returns:
- name
-
setName
public void setName(String name)
setName.
-
region
public SubAccountCreateTargetAccount region(String region)
region.- Returns:
- SubAccountCreateTargetAccount
-
getRegion
public String getRegion()
The region where the target account is in..- Returns:
- region
-
setRegion
public void setRegion(String region)
setRegion.
-
countryCode
public SubAccountCreateTargetAccount countryCode(String countryCode)
countryCode.- Returns:
- SubAccountCreateTargetAccount
-
getCountryCode
public String getCountryCode()
The country code where the target account is in..- Returns:
- countryCode
-
setCountryCode
public void setCountryCode(String countryCode)
setCountryCode.
-
site
public SubAccountCreateTargetAccount site(String site)
site.- Returns:
- SubAccountCreateTargetAccount
-
getSite
public String getSite()
The site where the target account is on..- Returns:
- site
-
setSite
public void setSite(String site)
setSite.
-
admin
public SubAccountCreateTargetAccount admin(SubAccountCreateTargetAccountAdmin admin)
admin.- Returns:
- SubAccountCreateTargetAccount
-
getAdmin
public SubAccountCreateTargetAccountAdmin getAdmin()
The admin user for the target account..- Returns:
- admin
-
setAdmin
public void setAdmin(SubAccountCreateTargetAccountAdmin admin)
setAdmin.
-
equals
public boolean equals(Object o)
Compares objects.
-
-