Class SubAccountCreateWorker

    • Constructor Detail

      • SubAccountCreateWorker

        public SubAccountCreateWorker()
    • Method Detail

      • getAssetGroupWorkId

        public UUID getAssetGroupWorkId()
        The create account work id..
        Returns:
        assetGroupWorkId
      • getAssetGroupId

        public UUID getAssetGroupId()
        The asset group id the accounts belong to..
        Returns:
        assetGroupId
      • getOrderId

        public UUID getOrderId()
        The order id created by the creation work..
        Returns:
        orderId
      • getAttempts

        public Integer getAttempts()
        The number of times the work has been attempted..
        Returns:
        attempts
      • getCreatedDate

        public String getCreatedDate()
        The date the account creation work is initiated..
        Returns:
        createdDate
      • getCreatedByName

        public String getCreatedByName()
        The name of the initiator of the account creation work..
        Returns:
        createdByName
      • getCreatedByEmail

        public String getCreatedByEmail()
        The email of the creator of the account creation work..
        Returns:
        createdByEmail
      • getMessage

        public String getMessage()
        The message associated with the account creation work..
        Returns:
        message
      • getCreateAccountProcessingFailureDetails

        public SubAccountErrorDetails getCreateAccountProcessingFailureDetails()
        The processing failures if the work is in PendingError/ProcessingError status..
        Returns:
        createAccountProcessingFailureDetails
      • equals

        public boolean equals​(Object o)
        Compares objects.
        Overrides:
        equals in class Object
        Returns:
        true or false depending on comparison result.
      • hashCode

        public int hashCode()
        Returns the HashCode.
        Overrides:
        hashCode in class Object
      • toString

        public String toString()
        Converts the given object to string.
        Overrides:
        toString in class Object