Package com.docusign.admin.model
Class SubAccountErrorDetails
- java.lang.Object
-
- com.docusign.admin.model.SubAccountErrorDetails
-
- All Implemented Interfaces:
Serializable
public class SubAccountErrorDetails extends Object implements Serializable
SubAccountErrorDetails.- See Also:
- Serialized Form
-
-
Constructor Summary
Constructors Constructor Description SubAccountErrorDetails()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(Object o)Compares objects.StringgetError()The error code..StringgetErrorDescription()The error description..inthashCode()Returns the HashCode.BooleanisIsSystemError()Whether the error is caused by the system or user..StringtoString()Converts the given object to string.
-
-
-
Method Detail
-
getError
public String getError()
The error code..- Returns:
- error
-
getErrorDescription
public String getErrorDescription()
The error description..- Returns:
- errorDescription
-
isIsSystemError
public Boolean isIsSystemError()
Whether the error is caused by the system or user..- Returns:
- isSystemError
-
equals
public boolean equals(Object o)
Compares objects.
-
-