Package com.docusign.admin.api
Class ProvisionAssetGroupApi
- java.lang.Object
-
- com.docusign.admin.api.ProvisionAssetGroupApi
-
public class ProvisionAssetGroupApi extends Object
ProvisionAssetGroupApi class.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description classProvisionAssetGroupApi.GetAssetGroupAccountCloneOptionsGetAssetGroupAccountCloneOptions Class.classProvisionAssetGroupApi.GetAssetGroupAccountClonesByOrgIdOptionsGetAssetGroupAccountClonesByOrgIdOptions Class.classProvisionAssetGroupApi.GetAssetGroupAccountsOptionsGetAssetGroupAccountsOptions Class.classProvisionAssetGroupApi.GetSubAccountCreateProcessByAssetGroupWorkIdOptionsGetSubAccountCreateProcessByAssetGroupWorkIdOptions Class.classProvisionAssetGroupApi.GetSubAccountCreateProcessesByOrgIdOptionsGetSubAccountCreateProcessesByOrgIdOptions Class.
-
Constructor Summary
Constructors Constructor Description ProvisionAssetGroupApi()ProvisionAssetGroupApi.ProvisionAssetGroupApi(ApiClient apiClient)ProvisionAssetGroupApi.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description AssetGroupAccountClonecloneAssetGroupAccount(UUID organizationId, AssetGroupAccountClone request)Clones an existing Docusign account to a new Docusign account..ApiResponse<AssetGroupAccountClone>cloneAssetGroupAccountWithHttpInfo(UUID organizationId, AssetGroupAccountClone request)Clones an existing Docusign account to a new Docusign account.SubscriptionProvisionModelAssetGroupWorkResultcreateAssetGroupAccount(UUID organizationId, SubAccountCreateRequest request)Creates a new Docusign account using the plan and modules specified in request body..ApiResponse<SubscriptionProvisionModelAssetGroupWorkResult>createAssetGroupAccountWithHttpInfo(UUID organizationId, SubAccountCreateRequest request)Creates a new Docusign account using the plan and modules specified in request body.ApiClientgetApiClient()getApiClient Method.AssetGroupAccountClonegetAssetGroupAccountClone(UUID organizationId, UUID assetGroupId, UUID assetGroupWorkId)Gets an asset group account clone by the asset group work id..AssetGroupAccountClonegetAssetGroupAccountClone(UUID organizationId, UUID assetGroupId, UUID assetGroupWorkId, ProvisionAssetGroupApi.GetAssetGroupAccountCloneOptions options)Gets an asset group account clone by the asset group work id..AssetGroupAccountClonesgetAssetGroupAccountClonesByOrgId(UUID organizationId)Gets all asset group account clone(s) for an organization id..AssetGroupAccountClonesgetAssetGroupAccountClonesByOrgId(UUID organizationId, ProvisionAssetGroupApi.GetAssetGroupAccountClonesByOrgIdOptions options)Gets all asset group account clone(s) for an organization id..ApiResponse<AssetGroupAccountClones>getAssetGroupAccountClonesByOrgIdWithHttpInfo(UUID organizationId, ProvisionAssetGroupApi.GetAssetGroupAccountClonesByOrgIdOptions options)Gets all asset group account clone(s) for an organization id.ApiResponse<AssetGroupAccountClone>getAssetGroupAccountCloneWithHttpInfo(UUID organizationId, UUID assetGroupId, UUID assetGroupWorkId, ProvisionAssetGroupApi.GetAssetGroupAccountCloneOptions options)Gets an asset group account clone by the asset group work id.AssetGroupAccountsResponsegetAssetGroupAccounts(UUID organizationId)Get all accounts in asset groups for the organization..AssetGroupAccountsResponsegetAssetGroupAccounts(UUID organizationId, ProvisionAssetGroupApi.GetAssetGroupAccountsOptions options)Get all accounts in asset groups for the organization..ApiResponse<AssetGroupAccountsResponse>getAssetGroupAccountsWithHttpInfo(UUID organizationId, ProvisionAssetGroupApi.GetAssetGroupAccountsOptions options)Get all accounts in asset groups for the organization.List<OrganizationSubscriptionResponse>getOrganizationPlanItems(UUID organizationId)Gets the subscription details for an organization id..ApiResponse<List<OrganizationSubscriptionResponse>>getOrganizationPlanItemsWithHttpInfo(UUID organizationId)Gets the subscription details for an organization id.SubAccountCreateWorkergetSubAccountCreateProcessByAssetGroupWorkId(UUID organizationId, UUID assetGroupId, UUID assetGroupWorkId)Gets an asset group account create process info by the asset group work id..SubAccountCreateWorkergetSubAccountCreateProcessByAssetGroupWorkId(UUID organizationId, UUID assetGroupId, UUID assetGroupWorkId, ProvisionAssetGroupApi.GetSubAccountCreateProcessByAssetGroupWorkIdOptions options)Gets an asset group account create process info by the asset group work id..ApiResponse<SubAccountCreateWorker>getSubAccountCreateProcessByAssetGroupWorkIdWithHttpInfo(UUID organizationId, UUID assetGroupId, UUID assetGroupWorkId, ProvisionAssetGroupApi.GetSubAccountCreateProcessByAssetGroupWorkIdOptions options)Gets an asset group account create process info by the asset group work id.SubAccountCreateWorkerResponsegetSubAccountCreateProcessesByOrgId(UUID organizationId)Gets all asset group account creation processes for an organization id..SubAccountCreateWorkerResponsegetSubAccountCreateProcessesByOrgId(UUID organizationId, ProvisionAssetGroupApi.GetSubAccountCreateProcessesByOrgIdOptions options)Gets all asset group account creation processes for an organization id..ApiResponse<SubAccountCreateWorkerResponse>getSubAccountCreateProcessesByOrgIdWithHttpInfo(UUID organizationId, ProvisionAssetGroupApi.GetSubAccountCreateProcessesByOrgIdOptions options)Gets all asset group account creation processes for an organization id.voidsetApiClient(ApiClient apiClient)setApiClient Method.
-
-
-
Constructor Detail
-
ProvisionAssetGroupApi
public ProvisionAssetGroupApi()
ProvisionAssetGroupApi.
-
ProvisionAssetGroupApi
public ProvisionAssetGroupApi(ApiClient apiClient)
ProvisionAssetGroupApi.
-
-
Method Detail
-
getApiClient
public ApiClient getApiClient()
getApiClient Method.- Returns:
- ApiClient
-
setApiClient
public void setApiClient(ApiClient apiClient)
setApiClient Method.
-
cloneAssetGroupAccount
public AssetGroupAccountClone cloneAssetGroupAccount(UUID organizationId, AssetGroupAccountClone request) throws ApiException
Clones an existing Docusign account to a new Docusign account.. Currently this only clones eSign settings and asset group information. Required scopes: asset_group_account_clone_write- Parameters:
organizationId- The Guid representing the organization id. (required)request- The request defails for the new asset group account clone. (required)- Returns:
- AssetGroupAccountClone
- Throws:
ApiException- if fails to make API call
-
cloneAssetGroupAccountWithHttpInfo
public ApiResponse<AssetGroupAccountClone> cloneAssetGroupAccountWithHttpInfo(UUID organizationId, AssetGroupAccountClone request) throws ApiException
Clones an existing Docusign account to a new Docusign account. Currently this only clones eSign settings and asset group information. Required scopes: asset_group_account_clone_write- Parameters:
organizationId- The Guid representing the organization id. (required)request- The request defails for the new asset group account clone. (required)- Returns:
- AssetGroupAccountClone
- Throws:
ApiException- if fails to make API call
-
createAssetGroupAccount
public SubscriptionProvisionModelAssetGroupWorkResult createAssetGroupAccount(UUID organizationId, SubAccountCreateRequest request) throws ApiException
Creates a new Docusign account using the plan and modules specified in request body.. Currently this only supports eSign plans and modules. Required scopes: organization_sub_account_write- Parameters:
organizationId- The Guid representing the organization id. (required)request- The request details for the new account. (required)- Returns:
- SubscriptionProvisionModelAssetGroupWorkResult
- Throws:
ApiException- if fails to make API call
-
createAssetGroupAccountWithHttpInfo
public ApiResponse<SubscriptionProvisionModelAssetGroupWorkResult> createAssetGroupAccountWithHttpInfo(UUID organizationId, SubAccountCreateRequest request) throws ApiException
Creates a new Docusign account using the plan and modules specified in request body. Currently this only supports eSign plans and modules. Required scopes: organization_sub_account_write- Parameters:
organizationId- The Guid representing the organization id. (required)request- The request details for the new account. (required)- Returns:
- SubscriptionProvisionModelAssetGroupWorkResult
- Throws:
ApiException- if fails to make API call
-
getAssetGroupAccountClone
public AssetGroupAccountClone getAssetGroupAccountClone(UUID organizationId, UUID assetGroupId, UUID assetGroupWorkId) throws ApiException
Gets an asset group account clone by the asset group work id.. Required scopes: asset_group_account_clone_read- Parameters:
organizationId- The Guid representing the organization id. (required)assetGroupId- The Guid representing the asset group id. (required)assetGroupWorkId- The Guid representing the asset group account clone id (required)- Returns:
- AssetGroupAccountClone
- Throws:
ApiException
-
getAssetGroupAccountClone
public AssetGroupAccountClone getAssetGroupAccountClone(UUID organizationId, UUID assetGroupId, UUID assetGroupWorkId, ProvisionAssetGroupApi.GetAssetGroupAccountCloneOptions options) throws ApiException
Gets an asset group account clone by the asset group work id.. Required scopes: asset_group_account_clone_read- Parameters:
organizationId- The Guid representing the organization id. (required)assetGroupId- The Guid representing the asset group id. (required)assetGroupWorkId- The Guid representing the asset group account clone id (required)options- for modifying the method behavior.- Returns:
- AssetGroupAccountClone
- Throws:
ApiException- if fails to make API call
-
getAssetGroupAccountCloneWithHttpInfo
public ApiResponse<AssetGroupAccountClone> getAssetGroupAccountCloneWithHttpInfo(UUID organizationId, UUID assetGroupId, UUID assetGroupWorkId, ProvisionAssetGroupApi.GetAssetGroupAccountCloneOptions options) throws ApiException
Gets an asset group account clone by the asset group work id. Required scopes: asset_group_account_clone_read- Parameters:
organizationId- The Guid representing the organization id. (required)assetGroupId- The Guid representing the asset group id. (required)assetGroupWorkId- The Guid representing the asset group account clone id (required)options- for modifying the method behavior.- Returns:
- AssetGroupAccountClone
- Throws:
ApiException- if fails to make API call
-
getAssetGroupAccountClonesByOrgId
public AssetGroupAccountClones getAssetGroupAccountClonesByOrgId(UUID organizationId) throws ApiException
Gets all asset group account clone(s) for an organization id.. Required scopes: asset_group_account_clone_read- Parameters:
organizationId- The Guid representing the organization id. (required)- Returns:
- AssetGroupAccountClones
- Throws:
ApiException
-
getAssetGroupAccountClonesByOrgId
public AssetGroupAccountClones getAssetGroupAccountClonesByOrgId(UUID organizationId, ProvisionAssetGroupApi.GetAssetGroupAccountClonesByOrgIdOptions options) throws ApiException
Gets all asset group account clone(s) for an organization id.. Required scopes: asset_group_account_clone_read- Parameters:
organizationId- The Guid representing the organization id. (required)options- for modifying the method behavior.- Returns:
- AssetGroupAccountClones
- Throws:
ApiException- if fails to make API call
-
getAssetGroupAccountClonesByOrgIdWithHttpInfo
public ApiResponse<AssetGroupAccountClones> getAssetGroupAccountClonesByOrgIdWithHttpInfo(UUID organizationId, ProvisionAssetGroupApi.GetAssetGroupAccountClonesByOrgIdOptions options) throws ApiException
Gets all asset group account clone(s) for an organization id. Required scopes: asset_group_account_clone_read- Parameters:
organizationId- The Guid representing the organization id. (required)options- for modifying the method behavior.- Returns:
- AssetGroupAccountClones
- Throws:
ApiException- if fails to make API call
-
getAssetGroupAccounts
public AssetGroupAccountsResponse getAssetGroupAccounts(UUID organizationId) throws ApiException
Get all accounts in asset groups for the organization.. Required scopes: asset_group_account_read- Parameters:
organizationId- The Guid representing the organization id. (required)- Returns:
- AssetGroupAccountsResponse
- Throws:
ApiException
-
getAssetGroupAccounts
public AssetGroupAccountsResponse getAssetGroupAccounts(UUID organizationId, ProvisionAssetGroupApi.GetAssetGroupAccountsOptions options) throws ApiException
Get all accounts in asset groups for the organization.. Required scopes: asset_group_account_read- Parameters:
organizationId- The Guid representing the organization id. (required)options- for modifying the method behavior.- Returns:
- AssetGroupAccountsResponse
- Throws:
ApiException- if fails to make API call
-
getAssetGroupAccountsWithHttpInfo
public ApiResponse<AssetGroupAccountsResponse> getAssetGroupAccountsWithHttpInfo(UUID organizationId, ProvisionAssetGroupApi.GetAssetGroupAccountsOptions options) throws ApiException
Get all accounts in asset groups for the organization. Required scopes: asset_group_account_read- Parameters:
organizationId- The Guid representing the organization id. (required)options- for modifying the method behavior.- Returns:
- AssetGroupAccountsResponse
- Throws:
ApiException- if fails to make API call
-
getOrganizationPlanItems
public List<OrganizationSubscriptionResponse> getOrganizationPlanItems(UUID organizationId) throws ApiException
Gets the subscription details for an organization id.. Currently charges and non e-sign assets are excluded in the response. Required scopes: organization_sub_account_read- Parameters:
organizationId- The Guid representing the organization id. (required)- Returns:
- java.util.List
- Throws:
ApiException- if fails to make API call
-
getOrganizationPlanItemsWithHttpInfo
public ApiResponse<List<OrganizationSubscriptionResponse>> getOrganizationPlanItemsWithHttpInfo(UUID organizationId) throws ApiException
Gets the subscription details for an organization id. Currently charges and non e-sign assets are excluded in the response. Required scopes: organization_sub_account_read- Parameters:
organizationId- The Guid representing the organization id. (required)- Returns:
- java.util.List
- Throws:
ApiException- if fails to make API call
-
getSubAccountCreateProcessByAssetGroupWorkId
public SubAccountCreateWorker getSubAccountCreateProcessByAssetGroupWorkId(UUID organizationId, UUID assetGroupId, UUID assetGroupWorkId) throws ApiException
Gets an asset group account create process info by the asset group work id.. Required scopes: organization_sub_account_read- Parameters:
organizationId- The Guid representing the organization id. (required)assetGroupId- The Guid representing the asset group id. (required)assetGroupWorkId- The Guid representing the asset group account create id (required)- Returns:
- SubAccountCreateWorker
- Throws:
ApiException
-
getSubAccountCreateProcessByAssetGroupWorkId
public SubAccountCreateWorker getSubAccountCreateProcessByAssetGroupWorkId(UUID organizationId, UUID assetGroupId, UUID assetGroupWorkId, ProvisionAssetGroupApi.GetSubAccountCreateProcessByAssetGroupWorkIdOptions options) throws ApiException
Gets an asset group account create process info by the asset group work id.. Required scopes: organization_sub_account_read- Parameters:
organizationId- The Guid representing the organization id. (required)assetGroupId- The Guid representing the asset group id. (required)assetGroupWorkId- The Guid representing the asset group account create id (required)options- for modifying the method behavior.- Returns:
- SubAccountCreateWorker
- Throws:
ApiException- if fails to make API call
-
getSubAccountCreateProcessByAssetGroupWorkIdWithHttpInfo
public ApiResponse<SubAccountCreateWorker> getSubAccountCreateProcessByAssetGroupWorkIdWithHttpInfo(UUID organizationId, UUID assetGroupId, UUID assetGroupWorkId, ProvisionAssetGroupApi.GetSubAccountCreateProcessByAssetGroupWorkIdOptions options) throws ApiException
Gets an asset group account create process info by the asset group work id. Required scopes: organization_sub_account_read- Parameters:
organizationId- The Guid representing the organization id. (required)assetGroupId- The Guid representing the asset group id. (required)assetGroupWorkId- The Guid representing the asset group account create id (required)options- for modifying the method behavior.- Returns:
- SubAccountCreateWorker
- Throws:
ApiException- if fails to make API call
-
getSubAccountCreateProcessesByOrgId
public SubAccountCreateWorkerResponse getSubAccountCreateProcessesByOrgId(UUID organizationId) throws ApiException
Gets all asset group account creation processes for an organization id.. Required scopes: organization_sub_account_read- Parameters:
organizationId- The Guid representing the organization id. (required)- Returns:
- SubAccountCreateWorkerResponse
- Throws:
ApiException
-
getSubAccountCreateProcessesByOrgId
public SubAccountCreateWorkerResponse getSubAccountCreateProcessesByOrgId(UUID organizationId, ProvisionAssetGroupApi.GetSubAccountCreateProcessesByOrgIdOptions options) throws ApiException
Gets all asset group account creation processes for an organization id.. Required scopes: organization_sub_account_read- Parameters:
organizationId- The Guid representing the organization id. (required)options- for modifying the method behavior.- Returns:
- SubAccountCreateWorkerResponse
- Throws:
ApiException- if fails to make API call
-
getSubAccountCreateProcessesByOrgIdWithHttpInfo
public ApiResponse<SubAccountCreateWorkerResponse> getSubAccountCreateProcessesByOrgIdWithHttpInfo(UUID organizationId, ProvisionAssetGroupApi.GetSubAccountCreateProcessesByOrgIdOptions options) throws ApiException
Gets all asset group account creation processes for an organization id. Required scopes: organization_sub_account_read- Parameters:
organizationId- The Guid representing the organization id. (required)options- for modifying the method behavior.- Returns:
- SubAccountCreateWorkerResponse
- Throws:
ApiException- if fails to make API call
-
-