Package com.docusign.admin.model
Class SubAccountCreateWorker
- java.lang.Object
-
- com.docusign.admin.model.SubAccountCreateWorker
-
- All Implemented Interfaces:
Serializable
public class SubAccountCreateWorker extends Object implements Serializable
SubAccountCreateWorker.- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classSubAccountCreateWorker.AssetGroupWorkTypeEnumThe type of asset group work.static classSubAccountCreateWorker.StatusEnumThe account creation status.
-
Constructor Summary
Constructors Constructor Description SubAccountCreateWorker()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(Object o)Compares objects.UUIDgetAssetGroupId()The asset group id the accounts belong to..UUIDgetAssetGroupWorkId()The create account work id..SubAccountCreateWorker.AssetGroupWorkTypeEnumgetAssetGroupWorkType()The type of asset group work..IntegergetAttempts()The number of times the work has been attempted..SubAccountErrorDetailsgetCreateAccountProcessingFailureDetails()The processing failures if the work is in PendingError/ProcessingError status..StringgetCreatedByEmail()The email of the creator of the account creation work..StringgetCreatedByName()The name of the initiator of the account creation work..StringgetCreatedDate()The date the account creation work is initiated..StringgetMessage()The message associated with the account creation work..UUIDgetOrderId()The order id created by the creation work..SubAccountCreateWorker.StatusEnumgetStatus()The account creation status..SubAccountCreateSubscriptionDetailsgetSubscriptionDetails()The subscription info to create the account.SubAccountCreateTargetAccountgetTargetAccount()The target account being created.inthashCode()Returns the HashCode.voidsetSubscriptionDetails(SubAccountCreateSubscriptionDetails subscriptionDetails)setSubscriptionDetails.voidsetTargetAccount(SubAccountCreateTargetAccount targetAccount)setTargetAccount.SubAccountCreateWorkersubscriptionDetails(SubAccountCreateSubscriptionDetails subscriptionDetails)subscriptionDetails.SubAccountCreateWorkertargetAccount(SubAccountCreateTargetAccount targetAccount)targetAccount.StringtoString()Converts the given object to string.
-
-
-
Method Detail
-
targetAccount
public SubAccountCreateWorker targetAccount(SubAccountCreateTargetAccount targetAccount)
targetAccount.- Returns:
- SubAccountCreateWorker
-
getTargetAccount
public SubAccountCreateTargetAccount getTargetAccount()
The target account being created.- Returns:
- targetAccount
-
setTargetAccount
public void setTargetAccount(SubAccountCreateTargetAccount targetAccount)
setTargetAccount.
-
subscriptionDetails
public SubAccountCreateWorker subscriptionDetails(SubAccountCreateSubscriptionDetails subscriptionDetails)
subscriptionDetails.- Returns:
- SubAccountCreateWorker
-
getSubscriptionDetails
public SubAccountCreateSubscriptionDetails getSubscriptionDetails()
The subscription info to create the account.- Returns:
- subscriptionDetails
-
setSubscriptionDetails
public void setSubscriptionDetails(SubAccountCreateSubscriptionDetails subscriptionDetails)
setSubscriptionDetails.
-
getAssetGroupWorkId
public UUID getAssetGroupWorkId()
The create account work id..- Returns:
- assetGroupWorkId
-
getAssetGroupId
public UUID getAssetGroupId()
The asset group id the accounts belong to..- Returns:
- assetGroupId
-
getAssetGroupWorkType
public SubAccountCreateWorker.AssetGroupWorkTypeEnum getAssetGroupWorkType()
The type of asset group work..- Returns:
- assetGroupWorkType
-
getStatus
public SubAccountCreateWorker.StatusEnum getStatus()
The account creation status..- Returns:
- status
-
getOrderId
public UUID getOrderId()
The order id created by the creation work..- Returns:
- orderId
-
getAttempts
public Integer getAttempts()
The number of times the work has been attempted..- Returns:
- attempts
-
getCreatedDate
public String getCreatedDate()
The date the account creation work is initiated..- Returns:
- createdDate
-
getCreatedByName
public String getCreatedByName()
The name of the initiator of the account creation work..- Returns:
- createdByName
-
getCreatedByEmail
public String getCreatedByEmail()
The email of the creator of the account creation work..- Returns:
- createdByEmail
-
getMessage
public String getMessage()
The message associated with the account creation work..- Returns:
- message
-
getCreateAccountProcessingFailureDetails
public SubAccountErrorDetails getCreateAccountProcessingFailureDetails()
The processing failures if the work is in PendingError/ProcessingError status..- Returns:
- createAccountProcessingFailureDetails
-
equals
public boolean equals(Object o)
Compares objects.
-
-